<?php

class WPEPAddOnMemberium extends WPEP_AddOn_Integration {

  protected static $_instance;

  /**
   * @return WPEP_AddOn_Integration
   */
  public static function instance() {
    if( self::$_instance === null )
      self::$_instance = new self();

    return self::$_instance;
  }

  public function get_name() {
    return "Memberium Integration";
  }

  public function get_information() {
    return array(
      'official'     => true,
      'store_id'     => '2775',
      'store_name'   => 'WpEp Memberium Integration',
      'version'      => '1.2.2',
      'store_author' => 'corrado izzo',// Worpdress user
      'link'         => 'codestore.codeiscode.com/downloads/wpep-memberium-integration/'
    );
  }

  public $sell_button_url  = '';
  public $sell_button_text = '';

  /**
   * Runs after WPEP has been fully loaded.
   * @return void
   */
  public function init() {
    $this->sell_button_text = get_option( 'wpep_addon_memberium_sell_button_text', 'Upgrade Membership Plan' );
    $this->sell_button_url  = get_option( 'wpep_addon_memberium_sell_button_url', '' );

    add_action( 'wpep_primary_content_before_grid', array( $this, 'before_grid_posts_query' ) );
    add_action( 'wpep_primary_content_after_grid', array( $this, 'after_grid_posts_query' ) );
    add_action( 'wpep_widget_content_before_grid', array( $this, 'before_grid_posts_query' ) );
    add_action( 'wpep_widget_content_after_grid', array( $this, 'after_grid_posts_query' ) );


    add_filter( 'wpep_course_link', array( $this, 'item_link' ), 100, 2 );
    add_filter( 'wpep_ebook_link', array( $this, 'item_link' ), 100, 2 );
    add_filter( 'wpep_video_link', array( $this, 'item_link' ), 100, 2 );

    add_filter( 'wpep_text_view_course', array( $this, 'item_action_text' ), 100, 2 );
    add_filter( 'wpep_text_download_ebook', array( $this, 'item_action_text' ), 100, 2 );
    add_filter( 'wpep_text_view_video', array( $this, 'item_action_text' ), 100, 2 );

    add_filter( 'wpep_grid_item_class', array( $this, 'grid_item_class'), 100, 2 );
    add_filter( 'wpep_widget_item_class', array( $this, 'grid_item_class'), 100, 2 );

    add_action( 'wp_footer', array( $this, 'add_plugin_css' ) );

    add_action( 'wpep_user_activity_lesson_status', array( $this, 'user_lesson_activity' ), 10, 3 );
  }

  public function grid_item_class( $class, $post_id ) {
    if( !function_exists( 'memb_hasPostAccess' ) )
      return $class;

    if( function_exists( 'memb_overrideProhibitedAction' ) )
      memb_overrideProhibitedAction('hide' );

    if( !memb_hasPostAccess( $post_id ) )
      $class .= ' ' . 'wpep-memberium-upgrade-required';

    if( function_exists( 'memb_overrideProhibitedAction' ) )
      memb_overrideProhibitedAction('show' );

    return $class;
  }

  public function item_link( $link, $post_id ) {
    if( !function_exists( 'memb_hasPostAccess' ) )
      return $link;

    if( function_exists( 'memb_overrideProhibitedAction' ) )
      memb_overrideProhibitedAction('hide' );

    if( !memb_hasPostAccess( $post_id ) ) {
      $individual_link = get_post_meta( $post_id, 'wpep_memberium_upgrade_link', true );

      if( $individual_link != '' && $individual_link != null )
        $link = $individual_link;
      else if( $this->sell_button_url != '' && $this->sell_button_url != null )
        $link = $this->sell_button_url;

    }

    if( function_exists( 'memb_overrideProhibitedAction' ) )
      memb_overrideProhibitedAction('show' );

    return $link;
  }

  public function item_action_text( $text, $post_id ) {
    if( !function_exists( 'memb_hasPostAccess' ) )
      return $text;

    if( function_exists( 'memb_overrideProhibitedAction' ) )
      memb_overrideProhibitedAction('hide' );

    if( !memb_hasPostAccess( $post_id ) )
      $text = $this->sell_button_text;

    if( function_exists( 'memb_overrideProhibitedAction' ) )
      memb_overrideProhibitedAction('show' );

    return $text;
  }

  public function before_grid_posts_query() {
    if( function_exists( 'memb_overrideProhibitedAction' ) )
      memb_overrideProhibitedAction('show');
  }

  public function after_grid_posts_query() {
    if( function_exists( 'memb_overrideProhibitedAction' ) )
      memb_overrideProhibitedAction('hide' );

  }

  public function user_lesson_activity($lesson_id, $is_completed, $user_id) {
    $lesson = WPEP\Entity\Course::instance()->get_lesson( $lesson_id );

    if( !function_exists( 'memb_setTags' ) )
      return false;

    if( isset( $lesson->options->memberium_tag ) && $lesson->options->memberium_tag != '' ) {
      foreach( explode(",", $lesson->options->memberium_tag ) as $tag )
        memb_setTags( ( $is_completed ? 1 : -1 ) * intval( $tag )  );
    }

    $section = WPEP\Entity\Course::instance()->get_section( $lesson->section_id );

    $this->_user_lesson_activity_section( $section, $is_completed, $user_id );
    $this->_user_lesson_activity_course( $section->post_id, $is_completed, $user_id );

    return true;
  }

  private function _user_lesson_activity_section( $section, $is_completed, $user_id ) {
    if( !isset( $section->options->memberium_tag ) || $section->options->memberium_tag == '' )
      return;

    $removeTags = true;

    if( $is_completed ) {
      $progress = WPEP\Controller::instance()->userActivity->course_progress_percentage( $section->post_id, $user_id, $section->id );

      $removeTags = ( $progress == 100 ? 0 : 1 );
    }

    foreach( explode(",", $section->options->memberium_tag ) as $tag )
      memb_setTags( ( $removeTags ? -1 : 1 ) * intval( $tag )  );

  }

  private function _user_lesson_activity_course( $course_id, $is_completed, $user_id ) {
    $removeTags = true;
    $memberium_tag = get_post_meta( $course_id, 'wpep_memberium_tag', true );

    if( $memberium_tag == null || $memberium_tag == '' )
      return;

    if( $is_completed ) {
      $progress = WPEP\Controller::instance()->userActivity->course_progress_percentage( $course_id, $user_id);

      $removeTags = ( $progress == 100 ? 0 : 1 );
    }

    foreach( explode(",", $memberium_tag ) as $tag )
      memb_setTags( ( $removeTags ? -1 : 1 ) * intval( $tag )  );

  }

  public function add_plugin_css() {
    echo '<style>
            .wpep-memberium-upgrade-required { opacity : 0.7; !important; }
            .wpep-memberium-upgrade-required.wpep-hidden { opacity : 0; !important; }
          </style>';
  }

}
