<?php

class WPEPAddOnMemberiumSettings extends WPEP_AddOn_Settings_Integration {

  protected static $_instance;

  /**
   * @return WPEP_AddOn_Integration
   */
  public static function instance() {
    if( self::$_instance === null )
      self::$_instance = new self();

    return self::$_instance;
  }

  public function get_name() {
    return WPEPAddOnMemberium::instance()->get_name();
  }

  public function get_alias() {
    return WPEPAddOnMemberium::instance()->get_alias();
  }

  public function get_field_list() {
    $current_license_status = get_option( 'wpep_addon_memberium_license_status', null );

    $license_status_text = '<p style="color:#4aa3df">' . __( "Please enter your license in order to receive automatic updates and support", 'wpep_memberium_integration' ) . '</p>';

    if( $current_license_status == 1 )
      $license_status_text = '<p style="color:#2ecc71">' . __( "Your License is Valid", "wpep_memberium_integration" ) . '</p>';
    else if( $current_license_status != null )
      $license_status_text = '<p style="color:#e74c3c">' . __( "Your License is invalid", "wpep_memberium_integration" ) . '</p>';

    $field_list = array(
      'sell_button_url' => array(
        'name'    => __( "Membership Plan Link", 'wpep_memberium_integration' ),
        'type'    => 'text',
        'value'   => get_option( 'wpep_addon_memberium_sell_button_url', '' ),
      ),
      'sell_button_text' => array(
        'name'    => __( "Buy Now Button", 'wpep_memberium_integration' ),
        'type'    => 'text',
        'value'   => get_option( 'wpep_addon_memberium_sell_button_text', 'Upgrade Membership Plan' ),
      ),
      'license' => array(
        'name'    => __( "License Key", 'wpep_custom_ui' ),
        'type'  => 'text',
        'value'   => get_option( 'wpep_addon_memberium_license', '' ),
        'description' => $license_status_text
      )
    );

    return $field_list;
  }

  public function save_information( $information ) {
    if( isset( $information['license'] ) && $information['license'] != '' ) {
      $current_license = get_option( 'wpep_addon_memberium_license_status', false );

      if( $current_license != $information['license'] ) {

        $plugin_information = WPEPAddOnMemberium::instance()->get_information();

        $api_params = array(
          'edd_action' => 'activate_license',
          'license'    => $information['license'],
          'item_id'    => $plugin_information['store_id']
        );

        $response = wp_remote_get(add_query_arg($api_params, 'http://codestore.codeiscode.com'), array('timeout' => 45, 'sslverify' => false));

        if ( !is_wp_error($response) ) {
          $license_data = json_decode(wp_remote_retrieve_body($response));

          if( $license_data->license == 'valid' ) {
            update_option( 'wpep_addon_memberium_license_status', 1 );
          } else {
            update_option( 'wpep_addon_memberium_license_status', 0 );
          }
        }

      }
    }

    foreach( $information as $information_key => $information_value )
      update_option( 'wpep_addon_memberium_' . $information_key, sanitize_text_field( $information_value ) );

    return true;
  }

}